---
name: Bug report
about: Create a report to help me improve cryoswath
title: ''
labels: bug
assignees: j-haacker

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. '....'
2. '....'

**Expected behavior**
A clear and concise description of what you expected to happen.

**Traceback**
Please add your error message in full **but without any security relevant details**.

**Environment**
Please provide information about your environment. Especially, include the pandas version.

**Additional context**
Add any other context about the problem here.
